@@ -11,6 +11,14 @@ from aldryn_mailchimp.forms import SubscriptionPluginForm
 from aldryn_mailchimp.models import SubscriptionPlugin
 
 
+ERROR_MESSAGES = {
+    104: _('Invalid API-Key'),
+    200: _('The selected list does not exist.'),
+    214: _('You are already subscribed to our list.'),
+    230: _('You are already subscribed to our list.'),
+}
+
+
 class SubscriptionView(FormView):
 
     form_class = SubscriptionPluginForm
@@ -22,7 +30,11 @@ class SubscriptionView(FormView):
         try:
             mailchimp_client.listSubscribe(id=plugin.list_id, email_address=form.cleaned_data['email'])
         except Exception, e:
-            messages.error(self.request, _(u'Oops, something must have gone wrong. Please try again later.'))
+            if hasattr(e, 'code') and e.code in ERROR_MESSAGES:
+                message = ERROR_MESSAGES.get(e.code)
+            else:
+                message = _(u'Oops, something must have gone wrong. Please try again later.')
+            messages.error(self.request, message)
         else:
-            messages.success(self.request, _(u'Successfully subscribed for mailing list.'))
+            messages.success(self.request, _(u'You have successfully subscribed to our mailing list.'))
         return redirect(form.cleaned_data['redirect_url'])
